#ifndef __GWEATHER_APPLET_H_
#define __GWEATHER_APPLET_H_

/* $Id: gweather-applet.h,v 1.10 2006/01/12 05:48:25 philipl Exp $ */

/*
 *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
 *
 *  This code released under the GNU GPL.
 *  Read the file COPYING for more information.
 *
 *  Main applet widget
 *
 */

#include "gweather.h"

G_BEGIN_DECLS

extern void gweather_applet_create(GWeatherApplet *gw_applet);
extern gint timeout_cb (gpointer data);
extern gint suncalc_timeout_cb (gpointer data);
extern void gweather_update (GWeatherApplet *applet);
extern void gweather_info_load (const gchar *path, GWeatherApplet *applet);
extern void gweather_info_save (const gchar *path, GWeatherApplet *applet);

G_END_DECLS

#endif /* __GWEATHER_APPLET_H_ */

